@@ -18,7 +18,6 @@ use serde::{Deserialize, Serialize};
 pub use db_adapter::{
     DBConnectOption, DBExecResult, DBPool, DBPoolConn, DBQuery, DBTx,
 };
-use py_sql::StringConvert;
 use crate::convert::StmtConvert;
 use crate::db::db_adapter::DataDecoder;
 
@@ -68,12 +67,11 @@ impl DBPoolOptions {
 pub struct DefaultDecoder {}
 
 impl DataDecoder for DefaultDecoder {
-    fn decode(&self, key: &str, data: &mut Bson) -> crate::Result<()> {
+    fn decode(&self, _key: &str, _data: &mut Bson) -> crate::Result<()> {
         return Ok(());
     }
 }
 
-
 #[derive(Serialize, Deserialize, Debug, Clone, Copy, Eq, PartialEq)]
 pub enum DriverType {
     None = 0,
